/* This file is part of Metaproxy.
   Copyright (C) Index Data

Metaproxy is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free
Software Foundation; either version 2, or (at your option) any later
version.

Metaproxy is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef METAPROXY_TORUS_HPP
#define METAPROXY_TORUS_HPP

#include <string>
#include <stdexcept>
#include <libxml/tree.h>

#include <metaproxy/package.hpp>

namespace metaproxy_1 {
    xmlDoc *get_searchable(Package &package,
                           std::string url_template, const std::string &db,
                           const std::string &query,
                           const std::string &realm,
                           const std::string &proxy,
                           std::string &addinfo);
}

#endif
/*
 * Local variables:
 * c-basic-offset: 4
 * c-file-style: "Stroustrup"
 * indent-tabs-mode: nil
 * End:
 * vim: shiftwidth=4 tabstop=8 expandtab
 */

